==> jc-1.4.0.tar.gz: gnu/xml/dom/DomEntity.h <==
// public class gnu.xml.dom.DomEntity

// class file dependencies
// @dep_class 5646b84495af96f8 gnu_xml_dom_DomEntity
// @dep_class 927ff3b1d72554f gnu_xml_dom_DomExtern
// @dep_class 5b5336c9987ffef5 gnu_xml_dom_DomNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomExtern

#include "gnu/xml/dom/DomExtern.h"

#ifndef _JC_gnu_xml_dom_DomEntity_H_
#define _JC_gnu_xml_dom_DomEntity_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomEntity$sub_refs	_jc_gnu_xml_dom_DomEntity$sub_refs;
typedef struct _jc_gnu_xml_dom_DomEntity$sub_nonrefs	_jc_gnu_xml_dom_DomEntity$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomEntity$refs	_jc_gnu_xml_dom_DomEntity$refs;
typedef struct _jc_gnu_xml_dom_DomEntity$nonrefs	_jc_gnu_xml_dom_DomEntity$nonrefs;
typedef struct _jc_gnu_xml_dom_DomEntity$object	_jc_gnu_xml_dom_DomEntity$object;

typedef const struct _jc_gnu_xml_dom_DomEntity$vmethods	_jc_gnu_xml_dom_DomEntity$vmethods;
typedef const struct _jc_gnu_xml_dom_DomEntity$vtable	_jc_gnu_xml_dom_DomEntity$vtable;
typedef const struct _jc_gnu_xml_dom_DomEntity$vtype	_jc_gnu_xml_dom_DomEntity$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomEntity$method$_init$1454edb578b4f0b8(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEntity$method$getBaseURI$1b139395df599840(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEntity$method$getInputEncoding$546bf75c8cbcf14f(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEntity$method$getNotationName$189660d5e1b465b0(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEntity$method$getXmlEncoding$4566fbb694fdecf9(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEntity$method$getXmlVersion$e238523151d504aa(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomEntity$method_info$getBaseURI$1b139395df599840;
extern _jc_method _jc_gnu_xml_dom_DomEntity$method_info$getInputEncoding$546bf75c8cbcf14f;
extern _jc_method _jc_gnu_xml_dom_DomEntity$method_info$getNotationName$189660d5e1b465b0;
extern _jc_method _jc_gnu_xml_dom_DomEntity$method_info$getXmlEncoding$4566fbb694fdecf9;
extern _jc_method _jc_gnu_xml_dom_DomEntity$method_info$getXmlVersion$e238523151d504aa;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomEntity$vmethods {
	struct _jc_java_lang_String$object	*(*getBaseURI$1b139395df599840)(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *);
	struct _jc_java_lang_String$object	*(*getInputEncoding$546bf75c8cbcf14f)(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *);
	struct _jc_java_lang_String$object	*(*getNotationName$189660d5e1b465b0)(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *);
	struct _jc_java_lang_String$object	*(*getXmlEncoding$4566fbb694fdecf9)(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *);
	struct _jc_java_lang_String$object	*(*getXmlVersion$e238523151d504aa)(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *);
};

// Vtable
struct _jc_gnu_xml_dom_DomEntity$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomExtern$vmethods	gnu_xml_dom_DomExtern;
	_jc_gnu_xml_dom_DomEntity$vmethods	gnu_xml_dom_DomEntity;
};

// Vtype
struct _jc_gnu_xml_dom_DomEntity$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomEntity$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEntity$sub_refs {
	struct _jc_java_lang_String$object	*notation;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomEntity$refs {
    _jc_gnu_xml_dom_DomEntity$sub_refs	gnu_xml_dom_DomEntity;
    _jc_gnu_xml_dom_DomExtern$sub_refs	gnu_xml_dom_DomExtern;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEntity$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomEntity$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomExtern$sub_nonrefs	gnu_xml_dom_DomExtern;
    _jc_gnu_xml_dom_DomEntity$sub_nonrefs	gnu_xml_dom_DomEntity;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomEntity$object {
	_jc_gnu_xml_dom_DomEntity$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomEntity$vtype	*vtype;
	_jc_gnu_xml_dom_DomEntity$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomEntity$vtype _jc_gnu_xml_dom_DomEntity$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomEntity, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomEntity$class_object;

#endif	/* _JC_gnu_xml_dom_DomEntity_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/dom/DomEntity.h <==
// public class gnu.xml.dom.DomEntity

// class file dependencies
// @dep_class 5646b84495af96f8 gnu_xml_dom_DomEntity
// @dep_class 927ff3b1d72554f gnu_xml_dom_DomExtern
// @dep_class 4ec94c6db3eac49b gnu_xml_dom_DomNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomExtern

#include "gnu/xml/dom/DomExtern.h"

#ifndef _JC_gnu_xml_dom_DomEntity_H_
#define _JC_gnu_xml_dom_DomEntity_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomEntity$sub_refs	_jc_gnu_xml_dom_DomEntity$sub_refs;
typedef struct _jc_gnu_xml_dom_DomEntity$sub_nonrefs	_jc_gnu_xml_dom_DomEntity$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomEntity$refs	_jc_gnu_xml_dom_DomEntity$refs;
typedef struct _jc_gnu_xml_dom_DomEntity$nonrefs	_jc_gnu_xml_dom_DomEntity$nonrefs;
typedef struct _jc_gnu_xml_dom_DomEntity$object	_jc_gnu_xml_dom_DomEntity$object;

typedef const struct _jc_gnu_xml_dom_DomEntity$vmethods	_jc_gnu_xml_dom_DomEntity$vmethods;
typedef const struct _jc_gnu_xml_dom_DomEntity$vtable	_jc_gnu_xml_dom_DomEntity$vtable;
typedef const struct _jc_gnu_xml_dom_DomEntity$vtype	_jc_gnu_xml_dom_DomEntity$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomEntity$method$_init$1454edb578b4f0b8(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEntity$method$getBaseURI$1b139395df599840(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEntity$method$getInputEncoding$546bf75c8cbcf14f(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEntity$method$getNotationName$189660d5e1b465b0(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEntity$method$getXmlEncoding$4566fbb694fdecf9(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEntity$method$getXmlVersion$e238523151d504aa(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomEntity$method_info$getBaseURI$1b139395df599840;
extern _jc_method _jc_gnu_xml_dom_DomEntity$method_info$getInputEncoding$546bf75c8cbcf14f;
extern _jc_method _jc_gnu_xml_dom_DomEntity$method_info$getNotationName$189660d5e1b465b0;
extern _jc_method _jc_gnu_xml_dom_DomEntity$method_info$getXmlEncoding$4566fbb694fdecf9;
extern _jc_method _jc_gnu_xml_dom_DomEntity$method_info$getXmlVersion$e238523151d504aa;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomEntity$vmethods {
	struct _jc_java_lang_String$object	*(*getBaseURI$1b139395df599840)(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getInputEncoding$546bf75c8cbcf14f)(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getNotationName$189660d5e1b465b0)(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getXmlEncoding$4566fbb694fdecf9)(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getXmlVersion$e238523151d504aa)(_jc_env *, struct _jc_gnu_xml_dom_DomEntity$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomEntity$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomExtern$vmethods	gnu_xml_dom_DomExtern;
	_jc_gnu_xml_dom_DomEntity$vmethods	gnu_xml_dom_DomEntity;
};

// Vtype
struct _jc_gnu_xml_dom_DomEntity$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomEntity$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEntity$sub_refs {
	struct _jc_java_lang_String$object	*notation;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomEntity$refs {
    _jc_gnu_xml_dom_DomEntity$sub_refs	gnu_xml_dom_DomEntity;
    _jc_gnu_xml_dom_DomExtern$sub_refs	gnu_xml_dom_DomExtern;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEntity$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomEntity$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomExtern$sub_nonrefs	gnu_xml_dom_DomExtern;
    _jc_gnu_xml_dom_DomEntity$sub_nonrefs	gnu_xml_dom_DomEntity;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomEntity$object {
	_jc_gnu_xml_dom_DomEntity$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomEntity$vtype	*vtype;
	_jc_gnu_xml_dom_DomEntity$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomEntity$vtype _jc_gnu_xml_dom_DomEntity$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomEntity, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomEntity$class_object;

#endif	/* _JC_gnu_xml_dom_DomEntity_H_ */
